@@ -16,7 +16,7 @@ impl ContextSw {
     pub fn new(header: Option<String>) -> Self {
         let header = header.unwrap_or_else(|| String::from("ContextSw"));
         let unit = String::new();
-        ContextSw {
+        Self {
             fmt_contents: HashMap::new(),
             raw_contents: HashMap::new(),
             width: 0,
