@@ -16,7 +16,7 @@ impl VmRss {
     pub fn new(header: Option<String>) -> Self {
         let header = header.unwrap_or_else(|| String::from("VmRSS"));
         let unit = String::from("[bytes]");
-        VmRss {
+        Self {
             fmt_contents: HashMap::new(),
             raw_contents: HashMap::new(),
             width: 0,
